@@ -62,7 +62,8 @@ KNSBackend * KNSResource::knsBackend() const
 
 QVariant KNSResource::icon() const
 {
-    return knsBackend()->iconName();
+    const QString thumbnail = m_entry.previewUrl(KNSCore::EntryInternal::PreviewSmall1);
+    return thumbnail.isEmpty() ? knsBackend()->iconName() : m_entry.previewUrl(KNSCore::EntryInternal::PreviewSmall1);
 }
 
 QString KNSResource::comment()
@@ -115,16 +116,6 @@ QUrl KNSResource::homepage()
     return m_entry.homepage();
 }
 
-QUrl KNSResource::thumbnailUrl()
-{
-    return QUrl(m_entry.previewUrl(KNSCore::EntryInternal::PreviewSmall1));
-}
-
-QUrl KNSResource::screenshotUrl()
-{
-    return QUrl(m_entry.previewUrl(KNSCore::EntryInternal::PreviewBig1));
-
-}
 void KNSResource::setEntry(const KNSCore::EntryInternal& entry)
 {
     const bool diff = entry.status() != m_entry.status();
@@ -210,6 +201,11 @@ QStringList KNSResource::executables() const
         return {};
 }
 
+QUrl KNSResource::url() const
+{
+    return QUrl(QStringLiteral("kns://")+knsBackend()->name() + QLatin1Char('/') + QUrl(m_entry.providerId()).host() + QLatin1Char('/') + m_entry.uniqueId());
+}
+
 void KNSResource::invokeApplication() const
 {
     QStringList exes = executables();
