@@ -385,6 +385,7 @@ void PackageKitBackend::refreshDatabase()
     if (!m_refresher) {
         acquireFetching(true);
         m_refresher = PackageKit::Daemon::refreshCache(false);
+        connect(m_refresher.data(), &PackageKit::Transaction::errorCode, this, &PackageKitBackend::transactionError);
         connect(m_refresher.data(), &PackageKit::Transaction::finished, this, [this]() {
             reloadPackageList();
             acquireFetching(false);
@@ -407,7 +408,7 @@ ResultsStream* PackageKitBackend::search(const AbstractResourcesBackend::Filters
         auto stream = new ResultsStream(QStringLiteral("PackageKitStream-search"));
         if (!ids.isEmpty()) {
             const auto resources = resourcesByPackageNames<QVector<AbstractResource*>>(ids);
-            QTimer::singleShot(0, this, [stream, resources, this] () {
+            QTimer::singleShot(0, this, [stream, resources] () {
                 stream->resourcesFound(resources);
             });
         }
