@@ -24,7 +24,7 @@
 #include <resources/AbstractResource.h>
 #include <resources/AbstractResourcesBackend.h>
 #include <QVariantList>
-#include "SnapSocket.h"
+#include <Snapd/Client>
 
 class QAction;
 class SnapReviewsBackend;
@@ -39,28 +39,34 @@ public:
     ResultsStream * search(const AbstractResourcesBackend::Filters & search) override;
     ResultsStream * findResourceByPackageName(const QUrl& search) override;
 
+    QString displayName() const override;
     int updatesCount() const override;
     AbstractBackendUpdater* backendUpdater() const override;
     AbstractReviewsBackend* reviewsBackend() const override;
-    bool isValid() const override { return true; } // No external file dependencies that could cause runtime errors
+    bool isValid() const override { return m_valid; }
     QList<QAction*> messageActions() const override { return {}; }
 
-    void installApplication(AbstractResource* app) override;
-    void installApplication(AbstractResource* app, const AddonList& addons) override;
-    void removeApplication(AbstractResource* app) override;
+    Transaction* installApplication(AbstractResource* app) override;
+    Transaction* installApplication(AbstractResource* app, const AddonList& addons) override;
+    Transaction* removeApplication(AbstractResource* app) override;
     bool isFetching() const override { return m_fetching; }
-    SnapSocket* socket() { return &m_socket; }
+    void checkForUpdates() override {}
+    bool hasApplications() const override { return true; }
+    QSnapdClient* client() { return &m_client; }
+    void refreshStates();
 
 private:
     void setFetching(bool fetching);
-    ResultsStream* populate(SnapJob* snaps, AbstractResource::State state);
+    template <class T>
+    ResultsStream* populate(T* snaps, AbstractResource::State state);
 
     QHash<QString, SnapResource*> m_resources;
     StandardBackendUpdater* m_updater;
     SnapReviewsBackend* m_reviews;
 
-    SnapSocket m_socket;
+    bool m_valid = true;
     bool m_fetching = false;
+    QSnapdClient m_client;
 };
 
 #endif // SNAPBACKEND_H
