@@ -22,11 +22,13 @@
 #include "SnapBackend.h"
 #include <QDebug>
 #include <QProcess>
+#include <QBuffer>
+#include <QImageReader>
 
-SnapResource::SnapResource(QJsonObject data, AbstractResource::State state, AbstractResourcesBackend* parent)
+SnapResource::SnapResource(QSharedPointer<QSnapdSnap> snap, AbstractResource::State state, SnapBackend* parent)
     : AbstractResource(parent)
     , m_state(state)
-    , m_data(std::move(data))
+    , m_snap(snap)
 {
 }
 
@@ -37,17 +39,17 @@ QString SnapResource::availableVersion() const
 
 QStringList SnapResource::categories()
 {
-    return {};
+    return { QStringLiteral("Application") };
 }
 
 QString SnapResource::comment()
 {
-    return m_data.value(QLatin1String("summary")).toString();
+    return m_snap->summary();
 }
 
 int SnapResource::size()
 {
-    return m_data.value(QLatin1String("installed-size")).toInt();
+    return m_snap->installedSize();
 }
 
 QUrl SnapResource::homepage()
@@ -57,12 +59,34 @@ QUrl SnapResource::homepage()
 
 QVariant SnapResource::icon() const
 {
-    return QUrl(m_data.value(QLatin1String("icon")).toString());
+    const auto iconPath = m_snap->icon();
+    if (iconPath.isEmpty())
+        return QStringLiteral("package-x-generic");
+
+    if (!iconPath.startsWith(QLatin1Char('/')))
+        return QUrl(iconPath);
+
+    auto backend = qobject_cast<SnapBackend*>(parent());
+    auto req = backend->client()->getIcon(packageName());
+    req->runSync();
+
+    if (req->error()) {
+        qWarning() << "icon error" << req->errorString() << iconPath;
+        return {};
+    }
+
+    auto icon = req->icon();
+
+    QBuffer buffer;
+    buffer.setData(icon->data());
+    QImageReader reader(&buffer);
+
+    return QVariant::fromValue<QImage>(reader.read());
 }
 
 QString SnapResource::installedVersion() const
 {
-    return m_data.value(QLatin1String("version")).toString();
+    return m_snap->version();
 }
 
 QString SnapResource::license()
@@ -72,32 +96,22 @@ QString SnapResource::license()
 
 QString SnapResource::longDescription()
 {
-    return m_data.value(QLatin1String("description")).toString();
+    return m_snap->description();
 }
 
 QString SnapResource::name()
 {
-    return m_data.value(QLatin1String("name")).toString();
+    return m_snap->name();
 }
 
 QString SnapResource::origin() const
 {
-    return QStringLiteral("snappy:") + m_data.value(QLatin1String("channel")).toString();
+    return QStringLiteral("snappy:") + m_snap->channel();
 }
 
 QString SnapResource::packageName() const
 {
-    return m_data.value(QLatin1String("name")).toString();
-}
-
-QUrl SnapResource::screenshotUrl()
-{
-    return {};
-}
-
-QUrl SnapResource::thumbnailUrl()
-{
-    return {};
+    return m_snap->name();
 }
 
 QString SnapResource::section()
@@ -110,6 +124,14 @@ AbstractResource::State SnapResource::state()
     return m_state;
 }
 
+void SnapResource::setState(AbstractResource::State state)
+{
+    if (m_state != state) {
+        m_state = state;
+        Q_EMIT stateChanged();
+    }
+}
+
 void SnapResource::fetchChangelog()
 {
     QString log;
@@ -118,27 +140,20 @@ void SnapResource::fetchChangelog()
 
 void SnapResource::fetchScreenshots()
 {
-    Q_EMIT screenshotsFetched({}, {});
+    QList<QUrl> screenshots;
+    for(int i = 0, c = m_snap->screenshotCount(); i<c; ++i) {
+        QScopedPointer<QSnapdScreenshot> screenshot(m_snap->screenshot(i));
+        screenshots << QUrl(screenshot->url());
+    }
+    Q_EMIT screenshotsFetched(screenshots, screenshots);
 }
 
 void SnapResource::invokeApplication() const
 {
-    QProcess::startDetached(m_data[QLatin1String("resource")].toString());
+//     QProcess::startDetached(m_snap->price());
 }
 
 bool SnapResource::isTechnical() const
 {
-    return m_data.value(QLatin1String("type")) == QLatin1String("os") || m_data.value(QLatin1String("private")).toBool();
-}
-
-void SnapResource::refreshState()
-{
-    auto b = qobject_cast<SnapBackend*>(backend());
-    SnapSocket* socket = b->socket();
-    auto job = socket->snapByName(packageName());
-    connect(job, &SnapJob::finished, this, [this](SnapJob* job){
-        m_state = job->isSuccessful() ? AbstractResource::Installed : AbstractResource::None;
-        Q_EMIT stateChanged();
-        qDebug() << "refreshed!!" << job->result() << job->statusCode() << m_state;
-    });
+    return m_snap->snapType() != QLatin1String("app");
 }
